@@ -1,9 +1,9 @@
-## Population Allele Locating Mapmaker v 2.0.3 20NOV2024
+## Population Allele Locating Mapmaker v2.0.8 16JUNE2025
 #'Population Allele Locating Mapmaker
 #'
 #'Produces a frequency heatmap for a specified allele, amino-acid motif, or haplotype based on the allele frequency data in the Solberg dataset.
 #'
-#'@param variant An allele or an amino acid motif in the following format: Locus*##$~##$~##$, where ## identifies a peptide position, and $ identifies an amino acid residue. Motifs can include any number of amino acids. Haplotypes must contain alleles that follow the aforementioned format, and may be delimited by "~" or "-".
+#'@param variant An allele or an amino acid motif in the following format: Locus*##$~##$~##$, where ## identifies a peptide position, and $ identifies an amino acid residue. Motifs can include any number of amino acids. Haplotypes must contain alleles that follow the aforementioned format, and must be delimited by "~".
 #'@param variantType Specifies whether the variant is an allele, motif, or haplotype.
 #'@param filename The full file path of the user specified dataset if the user wishes to use their own file, or the pre-bundled Solberg dataset or mock haplotype dataset. User provided datasets must be a .dat, .txt, or.csv file, and must conform to the structure and format of the datasets bundled with the package. Allele and motif datasets should follow the Solberg dataset format, and haplotype datasets should follow the SSHAARP haplotype mock data format.
 #'@param mask A logical parameter that determines if areas with little to no population coverage should be masked. The default value is set to FALSE.
@@ -22,6 +22,7 @@
 #'@importFrom dplyr filter %>% group_by summarise .data
 #'@importFrom stringr str_extract_all
 #'@importFrom filesstrings file.move
+#'@importFrom HLAtools getField
 #'
 #'@note IMGT protein alignments will be generated for the locus of the specified variant the first time PALM is executed for a given locus. The alignments will be saved to the temp directory and referenced by PALM. PALM checks if the locus specific alignment is present in the temp directory; if it is not, a protein alignment object will be built for the locus. Restarting the R session will remove existing alignments.
 #'@note The produced frequency heatmap is generated by using the Generic Mapping Tools (GMT) R Package, which is an interface between R and the GMT map making software.
@@ -66,6 +67,12 @@
 
 PALM<-function(variant, variantType, filename, mask=FALSE, color=TRUE, filterMigrant = TRUE, mapScale = TRUE, direct= getwd(), AFND=TRUE, generateLowFreq = TRUE, resolution = 500){
 
+  vTBool<-validateVariantType(variantType)
+
+  if(!vTBool){
+    return(warning("The entered value for the 'variantType' parameter is not valid. Please enter a valid value."))
+  }
+
   wd <- getwd()
   on.exit(setwd(wd))
 
@@ -103,9 +110,20 @@ PALM<-function(variant, variantType, filename, mask=FALSE, color=TRUE, filterMig
   #if locus is not present in the HLAalignments list, create protein alignment
   #and add it to the list object
   for(i in align_var){
+
     locus<-getVariantInfo(i)[[1]]
+
     if(!locus %in% names(HLAalignments)){
-      HLAalignments[[locus]]<-buildAlignments(locus, source = 'AA')[[1]]$AA
+
+      alignmentOut<-buildAlignments(locus, source = 'AA')[[1]]
+
+      #exit PALM() if warning message is returned from buildAlignments due to
+      #locus not being found in ANHIG alignments
+      if(!is.list(alignmentOut)){
+        return(invisible(NULL))
+      }
+
+      HLAalignments[[locus]]<-alignmentOut$AA
     }
   }
 
@@ -253,7 +271,7 @@ PALM<-function(variant, variantType, filename, mask=FALSE, color=TRUE, filterMig
     #if endMess is present in vAresults, truncate allele to two fields
     if(length(vAresults[[2]])!=0){
 
-      variant<-GetField(variant, Res=2)
+      variant<-getField(variant, 2, TRUE)
 
     }
   }
@@ -402,12 +420,12 @@ PALM<-function(variant, variantType, filename, mask=FALSE, color=TRUE, filterMig
     #use smaller font size if max allele frequency has more digits
     if(nchar(strsplit(as.character(decile_interval[2]), ".", fixed=T)[[1]][[2]]) >=5){
       #adds color scale to basemap based on cpt provided -- makes font on legend smaller
-      invisible(shell("for /f 'usebackq' %C in (`type filename`) do gmt psscale -Dx0.1i/0.9i/1.5i/0.3i -Cdecile.cpt --FONT_ANNOT_PRIMARY=10p,Helvetica,black -Np -L -O -K >> %C.ps", intern=T))
+      invisible(shell("for /f 'usebackq' %C in (`type filename`) do gmt psscale -Dx0.1i/0.9i/1.5i/0.3i -Cdecile.cpt --FONT_ANNOT_PRIMARY=14p,Helvetica,black -Np -L -O -K >> %C.ps", intern=T))
     }
 
     if(nchar(strsplit(as.character(decile_interval[2]), ".", fixed=T)[[1]][[2]]) <5){
       #adds color scale to basemap based on cpt provided -- makes font on legend smaller
-      invisible(shell("for /f 'usebackq' %C in (`type filename`) do gmt psscale -Dx0.1i/0.9i/1.5i/0.3i -Cdecile.cpt --FONT_ANNOT_PRIMARY=12p,Helvetica,black -Np -L -O -K >> %C.ps", intern=T))
+      invisible(shell("for /f 'usebackq' %C in (`type filename`) do gmt psscale -Dx0.1i/0.9i/1.5i/0.3i -Cdecile.cpt --FONT_ANNOT_PRIMARY=16p,Helvetica,black -Np -L -O -K >> %C.ps", intern=T))
     }
 
     invisible(shell("for /f 'usebackq' %C in (`type filename`) do gmt pscoast -JM6i -R-180/180/-60/80 -A30000 -Gc -O -K >> %C.ps", intern=T))
@@ -509,10 +527,10 @@ PALM<-function(variant, variantType, filename, mask=FALSE, color=TRUE, filterMig
 
     #use smaller font size if max allele frequency has more digits
     if(nchar(strsplit(as.character(format(decile_interval[2], scientific = FALSE)), ".", fixed=T)[[1]][[2]]) >=5){
-      gmt.system("gmt psscale -Dx0.1i/0.9i/1.5i/0.3i -Cdecile.cpt --FONT_ANNOT_PRIMARY=10p,Helvetica,black -Np -L -O -K >> `cat variant`.ps")
+      gmt.system("gmt psscale -Dx0.1i/0.9i/1.5i/0.3i -Cdecile.cpt --FONT_ANNOT_PRIMARY=14p,Helvetica,black -Np -L -O -K >> `cat variant`.ps")
     } else{
       #adds color scale to basemap based on cpt provided -- makes font on legend smaller
-      gmt.system("gmt psscale -Dx0.1i/0.9i/1.5i/0.3i -Cdecile.cpt --FONT_ANNOT_PRIMARY=12p,Helvetica,black -Np -L -O -K >> `cat variant`.ps")
+      gmt.system("gmt psscale -Dx0.1i/0.9i/1.5i/0.3i -Cdecile.cpt --FONT_ANNOT_PRIMARY=16p,Helvetica,black -Np -L -O -K >> `cat variant`.ps")
     }
 
     #overlays more coastlines with pscoast
