@@ -1,9 +1,9 @@
-##Dataset manipulation for motifs and alleles v 2.0.3 20NOV2024
+##Dataset manipulation for motifs and alleles v2.0.8 16JUNE2025
 #'Dataset manipulation for motifs and alleles
 #'
 #'Returns a modified version of the user selected dataset that includes a column of locus*allele names, is sorted by by population name, and is reduced to the specified locus. Cardinal coordinates are converted to their Cartesian equivalents (i.e. 50S is converted to -50).
 #'
-#'@param variant An allele or an amino acid motif in the following format: Locus*##$~##$~##$, where ## identifies a peptide position, and $ identifies an amino acid residue. Motifs can include any number of amino acids.
+#'@param variant An allele or an amino acid motif in the following format: Locus*##$~##$~##$, where ## identifies a peptide position, and $ identifies an amino acid residue. Motifs can include any number of amino acids. Haplotypes must contain alleles that follow the aforementioned format, and may be delimited by "~".
 #'@param filename The full file path of the user specified dataset if the user wishes to use their own file, or the pre-bundled Solberg dataset. User provided datasets must be a .dat, .txt, or.csv file, and must conform to the structure and format of the Solberg dataset.
 #'
 #'@importFrom utils read.delim
@@ -21,20 +21,14 @@ dataSubset<-function(variant, filename){
 
   dataset<-readFilename(filename, variant)
 
-  locusANHIG<-checkLocusANHIG(variant)
-
-  if(any(grepl(FALSE, locusANHIG[[1]]))==TRUE){
-    return(c(FALSE, locusANHIG[[2]]))
-  }
-
   locusDS<-checkLocusDataset(variant, filename)
 
   if(grepl(FALSE, locusDS[[1]])==TRUE){
     return(c(FALSE, locusDS[[2]]))
   }
 
-  #if locus is foundin ANHIG and in the dataset, extract locus information
-  if(grepl(TRUE, locusANHIG[[1]]) & grepl(TRUE, locusDS[[1]])){
+  #if locus is found in the dataset, extract locus information
+  if(grepl(TRUE, locusDS[[1]])){
     locus<-getVariantInfo(variant)[[1]]
   }
 
